(_api_lineshape)=
# Lineshapes

## Base Class
```{eval-rst}
.. autosummary::
    :toctree: generated/

    skretrieval.core.lineshape.LineShape

```

## Available Lineshapes
```{eval-rst}
.. autosummary::
    :toctree: generated/

    skretrieval.core.lineshape.Gaussian
    skretrieval.core.lineshape.Rectangle
    skretrieval.core.lineshape.DeltaFunction
    skretrieval.core.lineshape.UserLineShape

```
